@@ -14,7 +14,6 @@ from django.views.generic.base import View, TemplateView
 from django.views.generic.edit import FormView
 from django.contrib.auth.mixins import PermissionRequiredMixin
 from django.contrib.auth import views as auth_views
-
 from django.utils.translation import gettext_lazy as _
 
 from .forms import get_generic_form, ImportXlsForm
@@ -32,7 +31,7 @@ class GenericLoginView(auth_views.LoginView):
 class GenericDashboardView(PermissionRequiredMixin, TemplateView):
     models = []
     template_name = 'genviews/dashboard.html'
-    template_list_name = 'genviews/dashboard_list.html'
+    dflt_model_template = 'genviews/dashboard_tpl.html'
     list_cls = 'dashboard-list'
     auth = 'superuser'
 
@@ -48,13 +47,13 @@ class GenericDashboardView(PermissionRequiredMixin, TemplateView):
             model_dict = context['models'][m] = {}
             obj_count = m.get_view_data('dashboard', 'count') or settings.DASH_LIST_COUNT
             model_dict['title'] = m.get_view_data('dashboard', 'title')
-            model_dict['html'] = m.get_view_data('dashboard', 'html') or self.template_list_name
+            model_dict['html'] = m.get_view_data('dashboard', 'html') or self.dflt_model_template
             model_dict['menu'] = m.get_dash_menu()
             model_dict['fields'] = self.get_dash_fields(m)
             model_dict['list'] = m.objects.all()[:obj_count]
 
-        context['settings'] = settings
         context['layout_data'] = get_layout_data()
+        context['settings'] = settings
         return context
 
     def get_dash_fields(self, model):
@@ -88,6 +87,7 @@ class GenericOmnibarView(View):
 # LIST {{{1
 class GenericListView(PermissionRequiredMixin, ListView):
     template_name = 'genviews/list.html'
+    template_list_name = 'genviews/list_tpl.html'
     list_cls = 'generic-list'
     fields = '__all__' 
 
@@ -95,6 +95,7 @@ class GenericListView(PermissionRequiredMixin, ListView):
         assert hasattr(settings, 'FIELDMAP'), f"Pas de template FIELDMAP défini dans settings.py, il faut définir comment chaque field de la liste va s'afficher dans un template"
         self.current_app = self.model._meta.app_label
         self.permission_required = f'{self.current_app}.list_{self.model.__name__.lower()}'
+        self.template_name = self.model.get_view_data('list', 'tpl') or self.template_name
         super().__init__(**kwargs)
 
     def get_context_data(self, **kwargs):
@@ -104,6 +105,7 @@ class GenericListView(PermissionRequiredMixin, ListView):
         context['list_menu'] = self.model.get_list_menu()
         context['list_cls'] = self.list_cls
         context['fields'] = self.get_list_fields();
+        context['html'] = self.model.get_view_data('list', 'html') or self.template_list_name
 
         context['settings'] = settings
         context['layout_data'] = get_layout_data()
@@ -113,7 +115,6 @@ class GenericListView(PermissionRequiredMixin, ListView):
         view_struct_fields = self.model.get_view_data('list')
         return get_model_fields(self.model, view_struct_fields)
 
-
 # CREATE {{{1
 class GenericCreateView(PermissionRequiredMixin, CreateView):
     template_name = 'genviews/form.html'
@@ -122,6 +123,7 @@ class GenericCreateView(PermissionRequiredMixin, CreateView):
     def __init__(self, **kwargs):
         self.current_app = self.model._meta.app_label
         self.permission_required = f'{self.current_app}.add_{self.model.__name__.lower()}'
+        self.template_name = self.model.get_view_data('create', 'html') or self.template_name
 
         if not self.form_class:
             self.form_class = self.create_generic_form()
@@ -147,8 +149,8 @@ class GenericCreateView(PermissionRequiredMixin, CreateView):
         if len(self.color_classes) > 0:
             context['color_palette'] = get_color_from_class(self.color_classes)
 
-        context['settings'] = settings
         context['layout_data'] = get_layout_data()
+        context['settings'] = settings
         return context
 
     def get_success_url(self):
@@ -169,6 +171,8 @@ class GenericUpdateView(PermissionRequiredMixin, UpdateView):
         self.current_app = self.model._meta.app_label
         self.permission_required = f'{self.current_app}.change_{self.model.__name__.lower()}'
 
+        self.template_name = self.model.get_view_data('update', 'html') or self.template_name
+
         if not self.form_class:
             self.form_class = self.create_generic_form()
             # both fields and form_class not permitted
@@ -186,7 +190,7 @@ class GenericUpdateView(PermissionRequiredMixin, UpdateView):
         context['form_title'] = self.model.get_view_data('update', 'title')
         context['form_action'] = reverse_lazy(
           f"{self.current_app}:{self.model.__name__.lower()}-update", args=[self.object.pk])
-        
+
         if len(self.color_classes) > 0:
             context['color_palette'] = get_color_from_class(self.color_classes)
 
@@ -210,12 +214,13 @@ class GenericDetailView(PermissionRequiredMixin, DetailView):
     def __init__(self, **kwargs):
         self.current_app = self.model._meta.app_label
         self.permission_required = f'{self.current_app}.detail_{self.model.__name__.lower()}'
+        self.template_name = self.model.get_view_data('detail', 'tpl') or self.template_name
         super().__init__(**kwargs)
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
 
-        context['obj_html'] = self.model.get_view_data('detail', 'detail_html')
+        context['html'] = self.model.get_view_data('detail', 'html') or None
         context['MEDIA_URL'] = settings.MEDIA_URL
         context['detail_menu'] = self.object.get_view_menu('detail')
 
@@ -237,6 +242,7 @@ class GenericHistoryView(PermissionRequiredMixin, DetailView):
     def __init__(self, **kwargs):
         self.current_app = self.model._meta.app_label
         self.permission_required = f'{self.current_app}.history_{self.model.__name__.lower()}'
+        self.template_name = self.model.get_view_data('history', 'tpl') or self.template_name
         super().__init__(**kwargs)
 
     def get_context_data(self, **kwargs):
@@ -245,6 +251,7 @@ class GenericHistoryView(PermissionRequiredMixin, DetailView):
         context['list_menu'] = self.object.get_view_menu('history')
         context['object_list'] = self.object.history.all()
         context['fields'] = get_model_fields(self.model, self.fields)
+        context['html'] = self.model.get_view_data('history', 'html') or None
 
         context['settings'] = settings
         context['layout_data'] = get_layout_data()
@@ -258,12 +265,14 @@ class GenericDeleteView(PermissionRequiredMixin, DeleteView):
     def __init__(self, **kwargs):
         self.current_app = self.model._meta.app_label
         self.permission_required = f'{self.current_app}.delete_{self.model.__name__.lower()}'
+        self.template_name = self.model.get_view_data('delete', 'tpl') or self.template_name
         super().__init__(**kwargs)
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
         context['back_url'] = f"{self.current_app}:{self.model.__name__.lower()}-detail"
 
+        context['html'] = self.model.get_view_data('delete', 'html') or None
         context['settings'] = settings
         context['layout_data'] = get_layout_data()
         return context
@@ -274,6 +283,7 @@ class GenericDeleteView(PermissionRequiredMixin, DeleteView):
                 url = f"{self.current_app}:{self.model.__name__.lower()}-{v}"
                 return reverse_lazy(url, args=args)
 
+
 # EXPORT XLS {{{1
 class GenericExportxlsView(PermissionRequiredMixin, View):
     def __init__(self, **kwargs):
